BootManager

Struct BootManager 

pub struct BootManager { /* private fields */ }

Implementations

Source

impl BootManager

pub fn new( paths: KernelPaths, keep_last_kernel: bool, last_kernel_suffix: Option<String>, ) -> Self

Link kernel config file to kernel source directory.

Errors

Returns an error if file operations fail.

Update the /usr/src/linux symlink to point to the selected kernel.

Errors

Returns an error if symlink operations fail.

pub fn check_new_config_options( &self, kernel_path: &Path, ) -> Result<bool, BuilderErr>

Check if there are new kernel config options.

Errors

Returns an error if the command fails.

pub fn run_olddefconfig(&self, kernel_path: &Path) -> Result<(), BuilderErr>

Run make olddefconfig to integrate new kernel config options.

Errors

Returns an error if olddefconfig fails.

pub fn build_kernel( &self, kernel_path: &Path, threads: usize, ) -> Result<Output, BuilderErr>

Build the kernel with the specified number of threads.

Errors

Returns an error if the build fails.

pub fn install_kernel( &self, kernel_path: &Path, replace: bool, ) -> Result<(), BuilderErr>

Install the compiled kernel to the boot partition.

Errors

Returns an error if file operations fail.

pub fn install_modules(&self, kernel_path: &Path) -> Result<Output, BuilderErr>

Install kernel modules.

Errors

Returns an error if modules_install fails.

pub fn run_menuconfig(&self, kernel_path: &Path) -> Result<Output, BuilderErr>

Run menuconfig for kernel configuration.

Errors

Returns an error if menuconfig fails.